@@ -82,7 +82,8 @@ func TestAWK(t *testing.T) {
 		"t.intest2": true,
 	}
 	dontRunOnWindows := map[string]bool{
-		"p.50": true, // because this pipes to Unix sort "sort -t: +0 -1 +2nr"
+		"p.50":     true, // because this pipes to Unix sort "sort -t: +0 -1 +2nr"
+		"t.match1": true, // TODO: remove once https://lists.gnu.org/archive/html/bug-gawk/2025-10/msg00072.html is fixed and in choco (presumably 5.3.3)
 	}
 
 	infos, err := os.ReadDir(testsDir)
@@ -462,7 +463,7 @@ func TestDevStdout(t *testing.T) {
 	runAWKs(t, []string{`BEGIN { print "1"; print "2">"/dev/stdout" }`}, "", "1\n2\n", "")
 }
 
-func runGoAWK(args []string, stdin string) (stdout, stderr string, err error) {
+func runGoAWKRaw(args []string, stdin string) (stdout, stderr string, err error) {
 	cmd := exec.Command(goAWKExe, args...)
 	if stdin != "" {
 		cmd.Stdin = strings.NewReader(stdin)
@@ -470,8 +471,15 @@ func runGoAWK(args []string, stdin string) (stdout, stderr string, err error) {
 	errBuf := &bytes.Buffer{}
 	cmd.Stderr = errBuf
 	output, err := cmd.Output()
-	stdout = string(normalizeNewlines(output))
-	stderr = string(normalizeNewlines(errBuf.Bytes()))
+	stdout = string(output)
+	stderr = string(errBuf.Bytes())
+	return stdout, stderr, err
+}
+
+func runGoAWK(args []string, stdin string) (stdout, stderr string, err error) {
+	stdout, stderr, err = runGoAWKRaw(args, stdin)
+	stdout = string(normalizeNewlines([]byte(stdout)))
+	stderr = string(normalizeNewlines([]byte(stderr)))
 	return stdout, stderr, err
 }
 
@@ -696,6 +704,48 @@ $1 {
 	}
 }
 
+func TestNewlineOutputMode(t *testing.T) {
+	nl := "\n"
+	if runtime.GOOS == "windows" {
+		nl = "\r\n"
+	}
+
+	tests := []struct {
+		args   []string
+		input  string
+		output string
+		error  string
+	}{
+		{[]string{`BEGIN { printf 'foo\nbar\n' }`}, "", "foo" + nl + "bar" + nl, ""},
+		{[]string{"-N", "smart", `BEGIN { printf 'foo\nbar\n' }`}, "", "foo" + nl + "bar" + nl, ""},
+		{[]string{"-Nsmart", `BEGIN { printf 'foo\nbar\n' }`}, "", "foo" + nl + "bar" + nl, ""},
+		{[]string{"-N", "raw", `BEGIN { printf 'foo\nbar\n' }`}, "", "foo\nbar\n", ""},
+		{[]string{"-Nraw", `BEGIN { printf 'foo\nbar\n' }`}, "", "foo\nbar\n", ""},
+		{[]string{"-N", "crlf", `BEGIN { printf 'foo\nbar\n' }`}, "", "foo\r\nbar\r\n", ""},
+		{[]string{"-Ncrlf", `BEGIN { printf 'foo\nbar\n' }`}, "", "foo\r\nbar\r\n", ""},
+		{[]string{"-N", "INVALID", `BEGIN { printf 'foo\nbar\n' }`}, "", "", "-N arg can only be one of: smart, raw, crlf\n"},
+		{[]string{"-NINVALID", `BEGIN { printf 'foo\nbar\n' }`}, "", "", "-N arg can only be one of: smart, raw, crlf\n"},
+		{[]string{"-o", "csv", "-Nraw", `BEGIN { print 1, " 2 " }`}, "", "1,\" 2 \"\n", ""},
+		{[]string{"-o", "csv", "-Ncrlf", `BEGIN { print 1, " 2 " }`}, "", "1,\" 2 \"\r\n", ""},
+	}
+	for _, test := range tests {
+		testName := strings.Join(test.args, " ")
+		t.Run(testName, func(t *testing.T) {
+			stdout, stderr, err := runGoAWKRaw(test.args, test.input)
+			if err != nil {
+				if test.error == "" {
+					t.Fatalf("expected no error, got %v (%q)", err, stderr)
+				} else if stderr != test.error {
+					t.Fatalf("expected error message %q, got %q", test.error, stderr)
+				}
+			}
+			if stdout != test.output {
+				t.Fatalf("output differs, got:\n%s\nexpected:\n%s", stdout, test.output)
+			}
+		})
+	}
+}
+
 func TestMultipleCSVFiles(t *testing.T) {
 	// Ensure CSV handling works across multiple files with different headers (field names).
 	src := `
