@@ -40,8 +40,7 @@ var (
 
 	errCSVSeparator = errors.New("invalid CSV field separator or comment delimiter")
 
-	crlfNewline = runtime.GOOS == "windows"
-	varRegex    = regexp.MustCompile(`^([_a-zA-Z][_a-zA-Z0-9]*)=(.*)`)
+	varRegex = regexp.MustCompile(`^([_a-zA-Z][_a-zA-Z0-9]*)=(.*)`)
 
 	defaultShellCommand = getDefaultShellCommand()
 )
@@ -148,13 +147,14 @@ type interp struct {
 	ctxOps   int
 
 	// Misc pieces of state
-	random           *rand.Rand
-	randSeed         float64
-	exitStatus       int
-	regexCache       map[string]*regexp.Regexp
-	formatCache      map[string]cachedFormat
-	csvJoinFieldsBuf bytes.Buffer
-	chars            bool
+	random            *rand.Rand
+	randSeed          float64
+	exitStatus        int
+	regexCache        map[string]*regexp.Regexp
+	formatCache       map[string]cachedFormat
+	csvJoinFieldsBuf  bytes.Buffer
+	chars             bool
+	newlineOutputCRLF bool
 }
 
 // Various const configuration. Could make these part of Config if
@@ -170,6 +170,23 @@ const (
 	inputBufSize     = 64 * 1024
 )
 
+// NewlineMode specifies how newline characters are handled when reading or
+// writing text.
+type NewlineMode int
+
+const (
+	// SmartNewlineMode uses the newline mode most appropriate for the
+	// operating system: raw on Unix/Linux, crlf on Windows.
+	SmartNewlineMode NewlineMode = 0
+
+	// RawNewlineMode does no newline translation.
+	RawNewlineMode NewlineMode = 1
+
+	// CRLFNewlineMode forces the use of CRLF ("\r\n") newlines on output,
+	// regardless of the input format.
+	CRLFNewlineMode NewlineMode = 2
+)
+
 // Config defines the interpreter configuration for ExecProgram.
 type Config struct {
 	// Standard input reader (defaults to os.Stdin)
@@ -296,6 +313,11 @@ type Config struct {
 	// Set to true to count using Unicode chars instead of bytes for
 	// index(), length(), match(), substr(), and printf %c.
 	Chars bool
+
+	// NewlineOutput specifies how newline characters are handled when writing
+	// output. The default is "smart", meaning no translation on Linux/Unix
+	// and CRLF translation on Windows.
+	NewlineOutput NewlineMode
 }
 
 // IOMode specifies the input parsing or print output mode.
@@ -522,6 +544,17 @@ func (p *interp) setExecuteConfig(config *Config) error {
 		}
 	}
 
+	switch config.NewlineOutput {
+	case SmartNewlineMode:
+		p.newlineOutputCRLF = (runtime.GOOS == "windows")
+	case RawNewlineMode:
+		p.newlineOutputCRLF = false
+	case CRLFNewlineMode:
+		p.newlineOutputCRLF = true
+	default:
+		return fmt.Errorf("invalid newline output mode %d", config.NewlineOutput)
+	}
+
 	return nil
 }
 
@@ -800,6 +833,7 @@ func (p *interp) setSpecial(index int, v value) error {
 			if err != nil {
 				return newError("invalid regex %q: %s", p.fieldSep, err)
 			}
+			re.Longest() // other awks use leftmost-longest matching
 			p.fieldSepRegex = re
 		}
 	case ast.V_OFMT:
@@ -817,11 +851,13 @@ func (p *interp) setSpecial(index int, v value) error {
 			// Multi-byte unicode char falls back to regex splitter
 			sep := regexp.QuoteMeta(p.recordSep) // not strictly necessary as no multi-byte chars are regex meta chars
 			p.recordSepRegex = regexp.MustCompile(sep)
+			p.recordSepRegex.Longest() // other awks use leftmost-longest matching
 		default:
 			re, err := regexp.Compile(compiler.AddRegexFlags(p.recordSep))
 			if err != nil {
 				return newError("invalid regex %q: %s", p.recordSep, err)
 			}
+			re.Longest() // other awks use leftmost-longest matching
 			p.recordSepRegex = re
 		}
 	case ast.V_RT:
@@ -982,6 +1018,7 @@ func (p *interp) compileRegex(regex string) (*regexp.Regexp, error) {
 	if err != nil {
 		return nil, newError("invalid regex %q: %s", regex, err)
 	}
+	re.Longest() // other awks use leftmost-longest matching
 	// Dumb, non-LRU cache: just cache the first N regexes
 	if len(p.regexCache) < maxCachedRegexes {
 		p.regexCache[regex] = re
